@@ -1,11 +1,11 @@
 #ifndef FREERDP_BUILD_CONFIG_H
 #define FREERDP_BUILD_CONFIG_H
 
-#define FREERDP_DATA_PATH "/usr/pkg/share/freerdp2"
+#define FREERDP_DATA_PATH "/usr/local/share/freerdp2"
 #define FREERDP_KEYMAP_PATH ""
 #define FREERDP_PLUGIN_PATH "lib/freerdp2"
 
-#define FREERDP_INSTALL_PREFIX "/usr/pkg"
+#define FREERDP_INSTALL_PREFIX "/usr/local"
 
 #define FREERDP_LIBRARY_PATH "lib"
 
@@ -17,6 +17,6 @@
 #define FREERDP_VENDOR_STRING "FreeRDP"
 #define FREERDP_PRODUCT_STRING "FreeRDP"
 
-#define FREERDP_PROXY_PLUGINDIR "/tmp/pkgbuild/net/freerdp2/work.sparc/freerdp-2.11.7/cmake-pkgsrc-build/server/proxy/plugins"
+#define FREERDP_PROXY_PLUGINDIR "/usr/obj/ports/freerdp-2.3.2/build-aarch64/server/proxy/plugins"
 
 #endif /* FREERDP_BUILD_CONFIG_H */
